parsedatetime.tests.TestAustralianLocale

Package parsedatetime :: Package tests :: Module TestAustralianLocale |
[hide private]
[frames] | no frames]

# Module TestAustralianLocale

source code
Test parsing of simple date and times using the Australian locale

Classes | [hide private]
`` | test

Functions | [hide private]
`` | _compareResults(result, check)

Function Details | [hide private]

### _compareResults(result, check) | source code
None